use dotenv;

use tide::utils::After;

mod fs;
mod middleware;
mod post;
mod routes;

#[async_std::main]
async fn main() -> std::io::Result<()> {
    dotenv::dotenv().ok();
    tide::log::start();
    let mut app = tide::new();

    app.with(After(middleware::errors));
    app.with(middleware::session());

    app.at("/").get(routes::index);
    app.at("/posts")
        .with(middleware::require_auth)
        .post(routes::create_post);
    app.at("/posts/:id")
        .get(routes::single_post)
        .post(routes::update_post);
    app.at("/posts/:id/edit")
        .with(middleware::require_auth)
        .get(routes::edit_post);
    app.at("/login").get(routes::login_page).post(routes::login);
    app.at("/logout")
        .with(middleware::require_auth)
        .post(routes::logout);

    app.listen("127.0.0.1:8080").await?;

    Ok(())
}
